@@ -100,6 +100,7 @@ class AlignmentDataset(Dataset):
         tmp_directory=None,
         chunk_size=100,
         target_sampling_rate=None,
+        textgrid_url=None, # url to a zip file containing TextGrids
     ):
         super().__init__()
         __metaclass__ = abc.ABCMeta
@@ -125,6 +126,24 @@ class AlignmentDataset(Dataset):
             print(f"[green]✓[/green] {target_directory} already contains TextGrids")
             self._load_files()
             return
+        
+        if textgrid_url is not None:
+            # download textgrids
+            download_path = Path(f"{self.tmp_directory}/downloads")
+            download_path.mkdir(exist_ok=True, parents=True)
+            if textgrid_url.endswith(".zip"):
+                tmp_path = download_path / "data.zip"
+                response = request.urlretrieve(textgrid_url, tmp_path, DownloadProgressBar())
+                ZipFile(tmp_path).extractall(target_directory)
+            elif textgrid_url.endswith(".tar.gz"):
+                tmp_path = download_path / "data.tar.gz"
+                response = request.urlretrieve(textgrid_url, tmp_path, DownloadProgressBar())
+                tarfile.open(tmp_path).extractall(target_directory)
+            else:
+                raise ValueError("Unknown file type, only .zip and .tar.gz are supported.")
+            shutil.rmtree(download_path, ignore_errors=True)
+            self._load_files()
+            return
 
         # DOWNLOAD
         if self.source_url is not None:
